==> qmmp-0.6.0.tar.bz2: qmmp-0.6.0/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="45"/>
        <source>Show playlist manipulation commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="58"/>
        <source>List all available playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="59"/>
        <source>Show playlist content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="60"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="61"/>
        <source>Clear playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="62"/>
        <source>Toggle playlist repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="63"/>
        <source>Toggle playlist shuffle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="64"/>
        <source>Show playlist options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="83"/>
        <location filename="../playlistoption.cpp" line="101"/>
        <location filename="../playlistoption.cpp" line="116"/>
        <source>Invalid playlist ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="95"/>
        <source>Invalid number of arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <source>Invalid track ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="45"/>
        <source>Show playlist manipulation commands</source>
        <translation type="unfinished">Rodyti grojaraščio pagalbą</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="58"/>
        <source>List all available playlists</source>
        <translation type="unfinished">Rodyti visus grojaraščius</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="59"/>
        <source>Show playlist content</source>
        <translation type="unfinished">Rodyti grojaraščio turinį</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="60"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation type="unfinished">Groti takelį &lt;track&gt; grojaraštyje &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="61"/>
        <source>Clear playlist</source>
        <translation type="unfinished">Išvalyti grojaraštį</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="62"/>
        <source>Toggle playlist repeat</source>
        <translation type="unfinished">Įjungti grojaraščio kartojimą</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="63"/>
        <source>Toggle playlist shuffle</source>
        <translation type="unfinished">Įjungti grojaraščio sumaišymą</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="64"/>
        <source>Show playlist options</source>
        <translation type="unfinished">Rodyti grojaraščio pasirinkimus</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="83"/>
        <location filename="../playlistoption.cpp" line="101"/>
        <location filename="../playlistoption.cpp" line="116"/>
        <source>Invalid playlist ID</source>
        <translation type="unfinished">Neteisingas grojaraščio ID</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="95"/>
        <source>Invalid number of arguments</source>
        <translation type="unfinished">Neteisingas argumentų kiekis</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <source>Invalid track ID</source>
        <translation type="unfinished">Neteisingas takelio ID</translation>
    </message>
</context>
</TS>
